..  This file is part of kwalitee
    Copyright (C) 2014, 2015 CERN.

    kwalitee is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    kwalitee is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with kwalitee; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

    In applying this licence, CERN does not waive the privileges and immunities
    granted to it by virtue of its status as an Intergovernmental Organization
    or submit itself to any jurisdiction.


kwalitee package
========================

Subpackages
-----------

.. toctree::

    kwalitee.cli

Submodules
----------

kwalitee.config module
------------------------------

.. automodule:: kwalitee.config
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.factory module
-------------------------------

.. automodule:: kwalitee.factory
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.hooks module
-----------------------------

.. automodule:: kwalitee.hooks
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.kwalitee module
--------------------------------

.. automodule:: kwalitee.kwalitee
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.models module
------------------------------

.. automodule:: kwalitee.models
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.tasks module
-----------------------------

.. automodule:: kwalitee.tasks
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.views module
-----------------------------

.. automodule:: kwalitee.views
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.worker module
------------------------------

.. automodule:: kwalitee.worker
    :members:
    :undoc-members:
    :show-inheritance:

kwalitee.wsgi module
----------------------------

.. automodule:: kwalitee.wsgi
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kwalitee
    :members:
    :undoc-members:
    :show-inheritance:
